@@ -1,6 +1,6 @@
 import cv2
 import numpy as np
-import matplotlib.pyplot as plt
+from jcopvision.draw._cm import idx2color
 
 
 def draw_bbox(frame, pt1, pt2, color, label=None, conf=None, thickness=1, font=cv2.FONT_HERSHEY_SIMPLEX, fontsize=0.5,
@@ -52,7 +52,7 @@ def draw_bbox(frame, pt1, pt2, color, label=None, conf=None, thickness=1, font=c
         frame = (frame * 255).astype(np.uint8)
 
     if isinstance(color, int):
-        color = tuple(c*255 for c in plt.cm.Set1(color)[:3])
+        color = idx2color(color)
 
     if is_normalized:
         h, w, c = frame.shape
