@@ -18,7 +18,7 @@ class MP4Writer(BaseWriter):
     A video writer with mp4 compression.
     """
     def __init__(self, output_path, width, height, fps):
-        if output_path.endswith(".mp4"):
+        if not output_path.endswith(".mp4"):
             raise IncorrectExtensionError("output_path should have .mp4 extension")
 
         fourcc = cv2.VideoWriter_fourcc(*"MP4V")
@@ -30,7 +30,7 @@ class AVIWriter(BaseWriter):
     A video writer with avi compression.
     """
     def __init__(self, output_path, width, height, fps):
-        if output_path.endswith(".avi"):
+        if not output_path.endswith(".avi"):
             raise IncorrectExtensionError("output_path should have .avi extension")
 
         fourcc = cv2.VideoWriter_fourcc(*"MJPG")
